GlossyLinearGradient class

线性渐变效果类 输入参数:

  • begin: 渐变开始位置
  • end: 渐变结束位置
  • colors: 渐变颜色列表
  • tileMode: 渐变平铺模式
  • opacity: 整体透明度 输出: 通过 getLinearGradient() 方法返回 LinearGradient 对象
Inheritance

Constructors

GlossyLinearGradient({AlignmentGeometry begin = Alignment.centerLeft, AlignmentGeometry end = Alignment.centerRight, required List<Color> colors, TileMode tileMode = TileMode.clamp, required double opacity})
const

Properties

begin AlignmentGeometry
final
colors List<Color>
finalinherited
end AlignmentGeometry
final
hashCode int
The hash code for this object.
no setterinherited
opacity double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tileMode TileMode
final

Methods

getLinearGradient() LinearGradient
获取线性渐变对象 输出: 返回配置好的 LinearGradient 对象
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited